@@ -1,4 +1,4 @@
-# Copyright (C) 2009-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2009-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -22,8 +22,10 @@ import logging
 
 from email.utils import formataddr
 from enum import Enum
+from lazr.config import as_boolean
 from mailman.app.membership import delete_member
 from mailman.app.workflow import Workflow
+from mailman.config import config
 from mailman.core.i18n import _
 from mailman.database.transaction import flush
 from mailman.email.message import UserNotification
@@ -32,14 +34,23 @@ from mailman.interfaces.bans import IBanManager
 from mailman.interfaces.listmanager import ListDeletingEvent
 from mailman.interfaces.mailinglist import SubscriptionPolicy
 from mailman.interfaces.member import (
-    AlreadySubscribedError, DeliveryMode, DeliveryStatus, MemberRole,
-    MembershipIsBannedError, NotAMemberError)
+    AlreadySubscribedError,
+    DeliveryMode,
+    DeliveryStatus,
+    MemberRole,
+    MembershipIsBannedError,
+    NotAMemberError,
+)
 from mailman.interfaces.pending import IPendable, IPendings
 from mailman.interfaces.subscriptions import (
-    ISubscriptionManager, ISubscriptionService,
-    SubscriptionConfirmationNeededEvent, SubscriptionInvitationNeededEvent,
-    SubscriptionPendingError, TokenOwner,
-    UnsubscriptionConfirmationNeededEvent)
+    ISubscriptionManager,
+    ISubscriptionService,
+    SubscriptionConfirmationNeededEvent,
+    SubscriptionInvitationNeededEvent,
+    SubscriptionPendingError,
+    TokenOwner,
+    UnsubscriptionConfirmationNeededEvent,
+)
 from mailman.interfaces.template import ITemplateLoader
 from mailman.interfaces.user import IUser
 from mailman.interfaces.usermanager import IUserManager
@@ -226,17 +237,10 @@ class SubscriptionWorkflow(_SubscriptionWorkflowCommon):
         assert self.user is not None and self.address is not None, (
             'Insane sanity check results')
         # Is this subscriber already a member?
-        if (self.which is WhichSubscriber.user and
-                self.user.preferred_address is not None):
-            subscriber = self.user
-        else:
-            subscriber = self.address
-        if self.mlist.is_subscribed(subscriber):
-            # 2017-04-22 BAW: This branch actually *does* get covered, as I've
-            # verified by a full coverage run, but diffcov for some reason
-            # claims that the test added in the branch that added this code
-            # does not cover the change.  That seems like a bug in diffcov.
-            raise AlreadySubscribedError(           # pragma: nocover
+        if ((self.user.preferred_address == self.address and
+                self.mlist.is_subscribed(self.user)) or
+                self.mlist.is_subscribed(self.address)):
+            raise AlreadySubscribedError(
                 self.mlist.fqdn_listname,
                 self.address.email,
                 MemberRole.member)
@@ -322,8 +326,8 @@ class SubscriptionWorkflow(_SubscriptionWorkflowCommon):
         # Possibly send a notification to the list moderators.
         if self.mlist.admin_immed_notify:
             subject = _(
-                'New subscription request to $self.mlist.display_name '
-                'from $self.address.email')
+                'New subscription request to ${self.mlist.display_name} '
+                'from ${self.address.email}')
             username = formataddr(
                 (self.subscriber.display_name, self.address.email))
             template = getUtility(ITemplateLoader).get(
@@ -490,8 +494,8 @@ class UnSubscriptionWorkflow(_SubscriptionWorkflowCommon):
             self.mlist.fqdn_listname, self.address.email))
         if self.mlist.admin_immed_notify:
             subject = _(
-                'New unsubscription request to $self.mlist.display_name '
-                'from $self.address.email')
+                'New unsubscription request to ${self.mlist.display_name} '
+                'from ${self.address.email}')
             username = formataddr(
                 (self.subscriber.display_name, self.address.email))
             template = getUtility(ITemplateLoader).get(
@@ -622,14 +626,14 @@ def _handle_confirmation_needed_events(event, template_name):
     with _.using(event.mlist.preferred_language.code):
         if template_name.endswith(':invite'):
             subject = _('You have been invited to join the '
-                        '$event.mlist.fqdn_listname mailing list.')
+                        '${event.mlist.fqdn_listname} mailing list.')
         elif template_name.endswith(':unsubscribe'):
             subject = _('Your confirmation is needed to leave the '
-                        '$event.mlist.fqdn_listname mailing list.')
+                        '${event.mlist.fqdn_listname} mailing list.')
         else:
-            assert(template_name.endswith(':subscribe'))
+            assert template_name.endswith(':subscribe')
             subject = _('Your confirmation is needed to join the '
-                        '$event.mlist.fqdn_listname mailing list.')
+                        '${event.mlist.fqdn_listname} mailing list.')
     confirm_address = event.mlist.confirm_address(event.token)
     email_address = event.email
     # Send a verification email to the address.
@@ -645,6 +649,10 @@ def _handle_confirmation_needed_events(event, template_name):
         domain_name=event.mlist.domain.mail_host,
         contact_address=event.mlist.owner_address,
         ))
+    if ('verp_confirmations' in config.mta and not
+            as_boolean(config.mta.verp_confirmations)):
+        subject = 'confirm {}'.format(event.token)
+        confirm_address = event.mlist.request_address
     msg = UserNotification(
         email_address, confirm_address, subject, text,
         event.mlist.preferred_language)
