@@ -1,4 +1,4 @@
-# Copyright (C) 2009-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2009-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -32,7 +32,7 @@ from zope.interface import implementer
 
 
 def display_members(ctx, mlist, role, regular, digest,
-                    nomail, outfp, email_only):
+                    nomail, outfp, email_only, count_only):
     # Which type of digest recipients should we display?
     if digest == 'any':
         digest_types = [
@@ -40,6 +40,12 @@ def display_members(ctx, mlist, role, regular, digest,
             DeliveryMode.mime_digests,
             DeliveryMode.summary_digests,
             ]
+    elif digest == 'mime':
+        # Include summary with mime as they are currently treated alike.
+        digest_types = [
+            DeliveryMode.mime_digests,
+            DeliveryMode.summary_digests,
+            ]
     elif digest is not None:
         digest_types = [DeliveryMode[digest + '_digests']]
     else:
@@ -81,19 +87,21 @@ def display_members(ctx, mlist, role, regular, digest,
     # Print; outfp will be either the file or stdout to print to.
     addresses = list(roster.addresses)
     if len(addresses) == 0:
-        print(_('$mlist.list_id has no members'), file=outfp)
+        print(0 if count_only else _('${mlist.list_id} has no members'),
+              file=outfp)
+        return
+    if count_only:
+        print(roster.member_count, file=outfp)
         return
     for address in sorted(addresses, key=attrgetter('email')):
+        member = roster.get_member(address.email)
         if regular:
-            member = roster.get_member(address.email)
             if member.delivery_mode != DeliveryMode.regular:
                 continue
         if digest is not None:
-            member = roster.get_member(address.email)
             if member.delivery_mode not in digest_types:
                 continue
         if nomail is not None:
-            member = roster.get_member(address.email)
             if member.delivery_status not in status_types:
                 continue
         if email_only:
@@ -106,7 +114,7 @@ def display_members(ctx, mlist, role, regular, digest,
 @click.command(
     cls=I18nCommand,
     help=_("""\
-    Display, add or delete a mailing list's members.
+    Display a mailing list's members.
     Filtering along various criteria can be done when displaying.
     With no options given, displaying mailing list members
     to stdout is the default mode.
@@ -134,40 +142,45 @@ def display_members(ctx, mlist, role, regular, digest,
     '--output', '-o', 'outfp', metavar='FILENAME',
     type=click.File(mode='w', encoding='utf-8', atomic=True),
     help=_("""\
-    [MODE] Display output to FILENAME instead of stdout.  FILENAME
+    Display output to FILENAME instead of stdout.  FILENAME
     can be '-' to indicate standard output."""))
 @click.option(
     '--role', '-R',
     type=click.Choice(('any', 'owner', 'moderator', 'nonmember', 'member',
                        'administrator')),
     help=_("""\
-    [output filter] Display only members with a given ROLE.
+    Display only members with a given ROLE.
     The role may be 'any', 'member', 'nonmember', 'owner', 'moderator',
     or 'administrator' (i.e. owners and moderators).
-    If not given, then delivery members are used. """))
+    If not given, then 'member' role is assumed."""))
 @click.option(
     '--regular', '-r',
     is_flag=True, default=False,
     help=_("""\
-    [output filter] Display only regular delivery members."""))
+    Display only regular delivery members."""))
 @click.option(
     '--email-only', '-e', 'email_only',
     is_flag=True, default=False,
     help=("""\
-    [output filter] Display member addresses only, without the display name.
+    Display member addresses only, without the display name.
+    """))
+@click.option(
+    '--count-only', '-c', 'count_only',
+    is_flag=True, default=False,
+    help=("""\
+    Display members count only.
     """))
 @click.option(
     '--no-change', '-N', 'no_change',
     is_flag=True, default=False,
     help=_("""\
-    Don't actually make the changes.  Instead, print out what would be
-    done to the list."""))
+    This option has no effect. It exists for backwards compatibility only."""))
 @click.option(
     '--digest', '-d', metavar='kind',
     # baw 2010-01-23 summary digests are not really supported yet.
     type=click.Choice(('any', 'plaintext', 'mime')),
     help=_("""\
-    [output filter] Display only digest members of kind.
+    Display only digest members of kind.
     'any' means any digest type, 'plaintext' means only plain text (rfc 1153)
     type digests, 'mime' means MIME type digests."""))
 @click.option(
@@ -175,7 +188,7 @@ def display_members(ctx, mlist, role, regular, digest,
     type=click.Choice(('enabled', 'any', 'unknown',
                        'byadmin', 'byuser', 'bybounces')),
     help=_("""\
-    [output filter] Display only members with a given delivery status.
+    Display only members with a given delivery status.
     'enabled' means all members whose delivery is enabled, 'any' means
     members whose delivery is disabled for any reason, 'byuser' means
     that the member disabled their own delivery, 'bybounces' means that
@@ -186,10 +199,11 @@ def display_members(ctx, mlist, role, regular, digest,
 @click.argument('listspec')
 @click.pass_context
 def members(ctx, add_infp, del_infp, sync_infp, outfp,
-            role, regular, no_change, digest, nomail, listspec, email_only):
+            role, regular, no_change, digest, nomail, listspec,
+            email_only, count_only):
     mlist = getUtility(IListManager).get(listspec)
     if mlist is None:
-        ctx.fail(_('No such list: $listspec'))
+        ctx.fail(_('No such list: ${listspec}'))
     if add_infp is not None:
         ctx.fail('The --add option is removed. '
                  'Use `mailman addmembers` instead.')
@@ -199,9 +213,15 @@ def members(ctx, add_infp, del_infp, sync_infp, outfp,
     elif sync_infp is not None:
         ctx.fail('The --sync option is removed. '
                  'Use `mailman syncmembers` instead.')
+    elif role == 'any' and (regular or digest or nomail):
+        ctx.fail('The --regular, --digest and --nomail options are '
+                 'incompatible with role=any.')
+    elif email_only and count_only:
+        ctx.fail('The --email_only and --count_only options are '
+                 'mutually exclusive.')
     else:
         display_members(ctx, mlist, role, regular,
-                        digest, nomail, outfp, email_only)
+                        digest, nomail, outfp, email_only, count_only)
 
 
 @public
