@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2010-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -21,7 +21,7 @@ import sys
 import click
 import socket
 
-from mailman.bin.master import WatcherState, master_state
+from mailman.bin.master import master_state, WatcherState
 from mailman.core.i18n import _
 from mailman.interfaces.command import ICLISubCommand
 from mailman.utilities.options import I18nCommand
@@ -38,17 +38,17 @@ def status():
         message = _('GNU Mailman is not running')
     elif status is WatcherState.conflict:
         hostname, pid, tempfile = lock.details
-        message = _('GNU Mailman is running (master pid: $pid)')
+        message = _('GNU Mailman is running (master pid: ${pid})')
     elif status is WatcherState.stale_lock:
         hostname, pid, tempfile = lock.details
-        message = _('GNU Mailman is stopped (stale pid: $pid)')
+        message = _('GNU Mailman is stopped (stale pid: ${pid})')
     else:
         hostname, pid, tempfile = lock.details
         fqdn_name = socket.getfqdn()                         # noqa: F841
         assert status is WatcherState.host_mismatch, (
             'Invalid enum value: %s' % status)
         message = _('GNU Mailman is in an unexpected state '
-                    '($hostname != $fqdn_name)')
+                    '(${hostname} != ${fqdn_name})')
     print(message)
     sys.exit(status.value)
 
