@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -56,7 +56,7 @@ class Help:
             command_name = arguments[0]
             command = config.commands.get(command_name)
             if command is None:
-                print(_('$self.name: no such command: $command_name'),
+                print(_('${self.name}: no such command: ${command_name}'),
                       file=results)
                 return ContinueProcessing.no
             print('{} {}'.format(command.name, command.argument_description),
@@ -67,6 +67,7 @@ class Help:
             return ContinueProcessing.yes
         else:
             printable_arguments = SPACE.join(arguments)           # noqa: F841
-            print(_('$self.name: too many arguments: $printable_arguments'),
+            print(_('${self.name}: too many arguments: '
+                    '${printable_arguments}'),
                   file=results)
             return ContinueProcessing.no
