@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2015-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -29,8 +29,11 @@ from mailman.interfaces.digests import DigestFrequency
 from mailman.interfaces.member import DeliveryMode
 from mailman.runners.digest import DigestRunner
 from mailman.testing.helpers import (
-    get_queue_messages, make_testable_runner,
-    specialized_message_from_string as mfs, subscribe)
+    get_queue_messages,
+    make_testable_runner,
+    specialized_message_from_string as mfs,
+    subscribe,
+)
 from mailman.testing.layers import ConfigLayer
 from mailman.utilities.datetime import now as right_now
 
