@@ -1,4 +1,4 @@
-# Copyright (C) 2016-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -26,7 +26,7 @@ from email.errors import MessageError
 from mailman.app.lifecycle import create_list
 from mailman.commands.cli_gatenews import gatenews
 from mailman.config import config
-from mailman.testing.helpers import LogFileMark, get_queue_messages
+from mailman.testing.helpers import get_queue_messages, LogFileMark
 from mailman.testing.layers import ConfigLayer
 from unittest import TestCase
 from unittest.mock import patch
@@ -77,7 +77,7 @@ def get_nntplib_nntp(fail=0):
 
         def group(self, group_name):
             if group_name == 'my.group':
-                return('', 3, 1, 3, group_name)
+                return ('', 3, 1, 3, group_name)
             else:
                 raise nntplib.NNTPTemporaryError(
                     'No such group: {}'.format(group_name))
