@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -26,10 +26,15 @@ from mailman.interfaces.member import DeliveryMode
 from mailman.interfaces.runner import RunnerCrashEvent
 from mailman.runners.virgin import VirginRunner
 from mailman.testing.helpers import (
-    LogFileMark, configuration, event_subscribers, get_queue_messages,
-    make_digest_messages, make_testable_runner,
+    configuration,
+    event_subscribers,
+    get_queue_messages,
+    LogFileMark,
+    make_digest_messages,
+    make_testable_runner,
     specialized_message_from_string as mfs,
-    subscribe)
+    subscribe,
+)
 from mailman.testing.layers import ConfigLayer
 
 
