@@ -1,4 +1,4 @@
-# Copyright (C) 2008-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2008-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -21,13 +21,19 @@ from mailman.database.model import Model
 from mailman.database.transaction import dbconnection
 from mailman.database.types import SAUnicode, SAUnicode4Byte
 from mailman.interfaces.domain import (
-    BadDomainSpecificationError, DomainCreatedEvent, DomainCreatingEvent,
-    DomainDeletedEvent, DomainDeletingEvent, IDomain, IDomainManager)
+    BadDomainSpecificationError,
+    DomainCreatedEvent,
+    DomainCreatingEvent,
+    DomainDeletedEvent,
+    DomainDeletingEvent,
+    IDomain,
+    IDomainManager,
+)
 from mailman.interfaces.user import IUser
 from mailman.interfaces.usermanager import IUserManager
 from mailman.model.mailinglist import MailingList
 from public import public
-from sqlalchemy import Column, Integer
+from sqlalchemy import Column, func, Integer, select
 from sqlalchemy.orm import relationship
 from zope.component import getUtility
 from zope.event import notify
@@ -179,4 +185,8 @@ class DomainManager:
     @dbconnection
     def __contains__(self, store, mail_host):
         """See `IDomainManager`."""
-        return store.query(Domain).filter_by(mail_host=mail_host).count() > 0
+        stmt = (
+            select(func.count())
+            .select_from(Domain)
+            .filter_by(mail_host=mail_host))
+        return store.scalars(stmt).one() > 0
