@@ -1,4 +1,4 @@
-# Copyright (C) 2007-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2007-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -20,17 +20,26 @@
 from mailman.database.transaction import dbconnection
 from mailman.interfaces.address import InvalidEmailAddressError
 from mailman.interfaces.listmanager import (
-    IListManager, ListAlreadyExistsError, ListCreatedEvent, ListCreatingEvent,
-    ListDeletedEvent, ListDeletingEvent)
+    IListManager,
+    ListAlreadyExistsError,
+    ListCreatedEvent,
+    ListCreatingEvent,
+    ListDeletedEvent,
+    ListDeletingEvent,
+)
 from mailman.interfaces.requests import IListRequests
 from mailman.model.autorespond import AutoResponseRecord
 from mailman.model.bans import Ban
 from mailman.model.mailinglist import (
-    IAcceptableAliasSet, ListArchiver, MailingList)
+    IAcceptableAliasSet,
+    ListArchiver,
+    MailingList,
+)
 from mailman.model.mime import ContentFilter
 from mailman.utilities.datetime import now
 from mailman.utilities.queries import QuerySequence
 from public import public
+from sqlalchemy import select
 from zope.event import notify
 from zope.interface import implementer
 
@@ -120,7 +129,7 @@ class ListManager:
         """See `IListManager`."""
         result_set = store.query(MailingList)
         for list_id in result_set.values(MailingList._list_id):
-            assert isinstance(list_id, tuple) and len(list_id) == 1
+            assert len(list_id) == 1
             yield list_id[0]
 
     @property
@@ -134,10 +143,10 @@ class ListManager:
 
     @dbconnection
     def find(self, store, *, advertised=None, mail_host=None):
-        query = store.query(MailingList)
+        query = select(MailingList)
         if advertised is not None:
             query = query.filter_by(advertised=advertised)
         if mail_host is not None:
             query = query.filter_by(mail_host=mail_host)
         query = query.order_by(MailingList._list_id)
-        return QuerySequence(query)
+        return QuerySequence(store, query)
