@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2011-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -23,12 +23,18 @@ from datetime import datetime, timedelta
 from mailman.app.lifecycle import create_list, remove_list
 from mailman.database.transaction import transaction
 from mailman.interfaces.bounce import (
-    BounceContext, IBounceProcessor, InvalidBounceEvent)
+    BounceContext,
+    IBounceProcessor,
+    InvalidBounceEvent,
+)
 from mailman.interfaces.member import DeliveryStatus
 from mailman.interfaces.usermanager import IUserManager
 from mailman.testing.helpers import (
-    LogFileMark, configuration, get_queue_messages,
-    specialized_message_from_string as message_from_string)
+    configuration,
+    get_queue_messages,
+    LogFileMark,
+    specialized_message_from_string as message_from_string,
+)
 from mailman.testing.layers import ConfigLayer
 from mailman.utilities.datetime import now
 from zope.component import getUtility
@@ -301,7 +307,7 @@ Message-Id: <first>
                          ' been disabled')
 
     def test_send_warnings_and_remove_membership(self):
-        # Test that required number of warnings are send and then the the
+        # Test that required number of warnings are sent and then the
         # membership is removed.
         self._mlist.bounce_notify_owner_on_disable = False
         self._mlist.bounce_notify_owner_on_removal = True
