@@ -1,4 +1,4 @@
-# Copyright (C) 2017-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2017-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -22,7 +22,10 @@ import os
 from contextlib import ExitStack
 from importlib_resources import path
 from mailman.testing.helpers import (
-    TestableMaster, hackenv, wait_for_webservice)
+    hackenv,
+    TestableMaster,
+    wait_for_webservice,
+)
 from mailman.testing.layers import SMTPLayer
 from public import public
 
