@@ -17,6 +17,8 @@
 
 """REST for members."""
 
+import logging
+
 from lazr.config import as_boolean
 from mailman.app.membership import add_member
 from mailman.interfaces.action import Action
@@ -66,6 +68,9 @@ from uuid import UUID
 from zope.component import getUtility
 
 
+log = logging.getLogger('mailman.rest')
+
+
 class _MemberBase(CollectionMixin):
     """Shared base class for member representations."""
 
@@ -402,6 +407,7 @@ class AllMembers(_MemberBase):
                 conflict(response, b'Subscription request already pending')
                 return
             except Exception as e:
+                log.exception(e)
                 bad_request(response, str(e))
                 return
             if token is None:
