@@ -1,4 +1,4 @@
-# Copyright (C) 2014-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2014-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -33,10 +33,15 @@ from mailman.interfaces.member import DeliveryMode
 from mailman.interfaces.template import ITemplateManager
 from mailman.runners.digest import DigestRunner
 from mailman.testing.helpers import (
-    LogFileMark, digest_mbox, get_queue_messages, make_digest_messages,
-    make_testable_runner, message_from_string,
+    digest_mbox,
+    get_queue_messages,
+    LogFileMark,
+    make_digest_messages,
+    make_testable_runner,
+    message_from_string,
     specialized_message_from_string as mfs,
-    subscribe)
+    subscribe,
+)
 from mailman.testing.layers import ConfigLayer
 from string import Template
 from tempfile import TemporaryDirectory
