@@ -1,4 +1,4 @@
-# Copyright (C) 2016-2020 by the Free Software Foundation, Inc.
+# Copyright (C) 2016-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -27,8 +27,11 @@ from mailman.interfaces.mailinglist import SubscriptionPolicy
 from mailman.interfaces.usermanager import IUserManager
 from mailman.runners.command import CommandRunner
 from mailman.testing.helpers import (
-    get_queue_messages, make_testable_runner, set_preferred,
-    specialized_message_from_string as mfs)
+    get_queue_messages,
+    make_testable_runner,
+    set_preferred,
+    specialized_message_from_string as mfs,
+)
 from mailman.testing.layers import ConfigLayer
 from zope.component import getUtility
 
@@ -104,3 +107,38 @@ leave
                                          subaddress='leave'))
         self._runner.run()
         get_queue_messages('virgin', sort_on='subject', expected_count=0)
+
+    def test_leave_no_user_produces_response(self):
+        msg = mfs("""\
+From: anne@example.org
+To: test-leave@example.com
+
+leave
+""")
+        self._commandq.enqueue(msg, dict(listid='test.example.com',
+                                         subaddress='leave'))
+        self._runner.run()
+        # This should send out an error email.
+        get_queue_messages('virgin', expected_count=1)
+
+    def test_leave_unverified_produces_response(self):
+        with transaction():
+            self._mlist.unsubscription_policy = SubscriptionPolicy.confirm
+            anne = getUtility(IUserManager).create_user('anne@example.org')
+            set_preferred(anne)
+            self._mlist.subscribe(anne.preferred_address)
+            # Set address unverified.
+            anne.preferred_address.verified_on = None
+        msg = mfs("""\
+From: anne@example.org
+To: test-leave@example.com
+
+leave
+""")
+        # Clear virgin queue.
+        get_queue_messages('virgin')
+        self._commandq.enqueue(msg, dict(listid='test.example.com',
+                                         subaddress='leave'))
+        self._runner.run()
+        # This should send out an error email.
+        get_queue_messages('virgin', expected_count=1)
