@@ -1,4 +1,4 @@
-# Copyright (C) 2011-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2011-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -36,8 +36,12 @@ from mailman.interfaces.pending import IPendings
 from mailman.interfaces.usermanager import IUserManager
 from mailman.runners.outgoing import OutgoingRunner
 from mailman.testing.helpers import (
-    LogFileMark, configuration, get_queue_messages, make_testable_runner,
-    specialized_message_from_string as message_from_string)
+    configuration,
+    get_queue_messages,
+    LogFileMark,
+    make_testable_runner,
+    specialized_message_from_string as message_from_string,
+)
 from mailman.testing.layers import ConfigLayer, SMTPLayer
 from mailman.utilities.datetime import factory, now
 from zope.component import getUtility
@@ -328,6 +332,10 @@ Message-Id: <first>
         # But we can get the message.
         msg = getUtility(IMessageStore).get_message_by_id(event.message_id)
         self.assertEqual('SMTP Delivery Failure', msg.get('subject'))
+        self.assertEqual(f'Mailman <{self._mlist.posting_address}>',
+                         msg.get('From'))
+        self.assertEqual(f'Mailman Bounces <{self._mlist.bounces_address}>',
+                         msg.get('To'))
         self.assertIn('Error code: 500', msg.as_string())
         self.assertIn('Error message: Failure', msg.as_string())
 
@@ -371,6 +379,10 @@ Message-Id: <first>
         # Check the fake DSN we created.
         msg = getUtility(IMessageStore).get_message_by_id(events[0].message_id)
         self.assertEqual('SMTP Delivery Failure', msg.get('subject'))
+        self.assertEqual(f'Mailman <{self._mlist.posting_address}>',
+                         msg.get('From'))
+        self.assertEqual(f'Mailman Bounces <{self._mlist.bounces_address}>',
+                         msg.get('To'))
         self.assertIn('Error code: 500', msg.as_string())
         self.assertIn('Error message: Failure', msg.as_string())
 
@@ -389,10 +401,18 @@ Message-Id: <first>
         # Check the fake DSNs we created.
         msg = getUtility(IMessageStore).get_message_by_id(events[0].message_id)
         self.assertEqual('SMTP Delivery Failure', msg.get('subject'))
+        self.assertEqual(f'Mailman <{self._mlist.posting_address}>',
+                         msg.get('From'))
+        self.assertEqual(f'Mailman Bounces <{self._mlist.bounces_address}>',
+                         msg.get('To'))
         self.assertIn('Error code: 500', msg.as_string())
         self.assertIn('Error message: Failure', msg.as_string())
         msg = getUtility(IMessageStore).get_message_by_id(events[1].message_id)
         self.assertEqual('SMTP Delivery Failure', msg.get('subject'))
+        self.assertEqual(f'Mailman <{self._mlist.posting_address}>',
+                         msg.get('From'))
+        self.assertEqual(f'Mailman Bounces <{self._mlist.bounces_address}>',
+                         msg.get('To'))
         self.assertIn('Error code: 501', msg.as_string())
         self.assertIn('Error message: Another Failure', msg.as_string())
 
@@ -450,10 +470,18 @@ Message-Id: <first>
         # Check the fake DSNs we created.
         msg = getUtility(IMessageStore).get_message_by_id(events[0].message_id)
         self.assertEqual('SMTP Delivery Failure', msg.get('subject'))
+        self.assertEqual(f'Mailman <{self._mlist.posting_address}>',
+                         msg.get('From'))
+        self.assertEqual(f'Mailman Bounces <{self._mlist.bounces_address}>',
+                         msg.get('To'))
         self.assertIn('Error code: 500', msg.as_string())
         self.assertIn('Error message: Failure', msg.as_string())
         msg = getUtility(IMessageStore).get_message_by_id(events[1].message_id)
         self.assertEqual('SMTP Delivery Failure', msg.get('subject'))
+        self.assertEqual(f'Mailman <{self._mlist.posting_address}>',
+                         msg.get('From'))
+        self.assertEqual(f'Mailman Bounces <{self._mlist.bounces_address}>',
+                         msg.get('To'))
         self.assertIn('Error code: 501', msg.as_string())
         self.assertIn('Error message: Another Failure', msg.as_string())
         # Let's look at the temporary failures.
