@@ -1,4 +1,4 @@
-# Copyright (C) 2010-2021 by the Free Software Foundation, Inc.
+# Copyright (C) 2010-2022 by the Free Software Foundation, Inc.
 #
 # This file is part of GNU Mailman.
 #
@@ -39,11 +39,16 @@ from mailman.interfaces.digests import DigestFrequency
 from mailman.interfaces.errors import MailmanError
 from mailman.interfaces.languages import ILanguageManager
 from mailman.interfaces.mailinglist import (
-    DMARCMitigateAction, IAcceptableAliasSet, IHeaderMatchList,
-    Personalization, ReplyToMunging, SubscriptionPolicy)
+    DMARCMitigateAction,
+    IAcceptableAliasSet,
+    IHeaderMatchList,
+    Personalization,
+    ReplyToMunging,
+    SubscriptionPolicy,
+)
 from mailman.interfaces.member import DeliveryMode, DeliveryStatus, MemberRole
 from mailman.interfaces.nntp import NewsgroupModeration
-from mailman.interfaces.template import ITemplateLoader, ITemplateManager
+from mailman.interfaces.template import ITemplateLoader
 from mailman.interfaces.usermanager import IUserManager
 from mailman.model.roster import RosterVisibility
 from mailman.utilities.filesystem import makedirs
@@ -53,6 +58,7 @@ from sqlalchemy import Boolean
 from urllib.error import URLError
 from zope.component import getUtility
 
+
 log = logging.getLogger('mailman.error')
 
 
@@ -404,6 +410,8 @@ def import_config_pck(mlist, config_dict):
         # but .add() would not raise ValueError if address contained '@' and
         # that needs the '^' too as it could be a regexp with an '@' in it.
         alias_set.add(address)
+    # MM 2.1 accepts the listname as a local part regardless of domain.
+    alias_set.add('^' + mlist.list_name + '@')
     # Handle roster visibility.
     mapping = member_roster_visibility_mapping(
         config_dict.get('private_roster', None))
@@ -462,7 +470,7 @@ def import_config_pck(mlist, config_dict):
     # special `mailman:` scheme indicating a file system path.  What we do
     # here is look to see if the list's decoration is different than the
     # default, and if so, we'll write the new decoration template to a
-    # `mailman:` scheme path, then add the template to the template manager.
+    # `mailman:` scheme path which is in the standard search path.
     # We are intentionally omitting the 2.1 welcome_msg here because the
     # string is actually interpolated into a larger template and there's
     # no good way to figure where in the default template to insert it.
@@ -482,12 +490,21 @@ def import_config_pck(mlist, config_dict):
         ('%(real_name)s@%(host_name)s',
          'To unsubscribe send an email to ${short_listname}-leave@${domain}'),
         ('%(real_name)s mailing list',
-         '$display_name mailing list -- $listname'),
+         '${display_name} mailing list -- ${listname}'),
         # The generic footers no longer have URLs in them.
         ('%(web_page_url)slistinfo%(cgiext)s/%(_internal_name)s\n', ''),
+        # Additional simple replacement conversions.
+        ('%(real_name)s', '${display_name}'),
+        ('%(list_name)s', '${listname}'),
+        ('%(description)s', '${description}'),
+        ('%(info)s', '${info}'),
+        ('%(cgiext)s', ''),
+        ('%(user_address)s', '${user_email}'),
+        ('%(user_delivered_to)s', '${user_delivered_to}'),
+        ('%(user_password)s', ''),
+        ('%(user_name)s', '${user_name}'),
         ]
     # Collect defaults.
-    manager = getUtility(ITemplateManager)
     defaults = {}
     for oldvar, newvar in convert_to_uri.items():
         default_value = getUtility(ITemplateLoader).get(newvar, mlist)
@@ -502,7 +519,7 @@ def import_config_pck(mlist, config_dict):
             # more harm than good and it's easy to change if needed.
             # TESTME
             print('Unable to convert mailing list attribute:', oldvar,
-                  'with old value "{}"'.format(default_value),
+                  'with bad replacements in "{}"'.format(default_value),
                   file=sys.stderr)
             continue
         defaults[newvar] = default_text
@@ -535,11 +552,12 @@ def import_config_pck(mlist, config_dict):
                 expanded_text.strip() == default_text.strip()):
             # Keep the default.
             continue
-        # Write the custom value to the right file and add it to the template
-        # manager for real.
-        base_uri = 'mailman:///$listname/$language/'
+        if expanded_text and '%' in expanded_text:
+            print('Unable to convert mailing list attribute:', oldvar,
+                  'with value "{}"'.format(text),
+                  file=sys.stderr)
+        # Write the custom value to the right file.
         filename = '{}.txt'.format(newvar)
-        manager.set(newvar, mlist.list_id, base_uri + filename)
         with ExitStack() as resources:
             filepath = list(search(resources, filename, mlist))[0]
         makedirs(os.path.dirname(filepath))
@@ -682,18 +700,23 @@ def _import_roster(mlist, config_dict, members, role, action=None):
         # if email in config_dict.get('passwords', {}):
         #     user.password = config.password_context.encrypt(
         #         config_dict['passwords'][email])
-        # delivery_status
-        oldds = config_dict.get('delivery_status', {}).get(email, (0, 0))[0]
-        if oldds == 0:
+        # delivery_status - for members. owners/moderators are always enabled.
+        if role in (MemberRole.owner, MemberRole.moderator):
             member.preferences.delivery_status = DeliveryStatus.enabled
-        elif oldds == 1:
-            member.preferences.delivery_status = DeliveryStatus.unknown
-        elif oldds == 2:
-            member.preferences.delivery_status = DeliveryStatus.by_user
-        elif oldds == 3:
-            member.preferences.delivery_status = DeliveryStatus.by_moderator
-        elif oldds == 4:
-            member.preferences.delivery_status = DeliveryStatus.by_bounces
+        else:
+            oldds = config_dict.get(
+                'delivery_status', {}).get(email, (0, 0))[0]
+            if oldds == 0:
+                member.preferences.delivery_status = DeliveryStatus.enabled
+            elif oldds == 1:
+                member.preferences.delivery_status = DeliveryStatus.unknown
+            elif oldds == 2:
+                member.preferences.delivery_status = DeliveryStatus.by_user
+            elif oldds == 3:
+                member.preferences.delivery_status = \
+                    DeliveryStatus.by_moderator
+            elif oldds == 4:
+                member.preferences.delivery_status = DeliveryStatus.by_bounces
         # Moderation.
         if prefs is not None:
             # We're adding a member.
