@@ -19,6 +19,7 @@
 
 from collections.abc import Sequence
 from public import public
+from sqlalchemy import func, select
 
 
 @public
@@ -28,20 +29,48 @@ class QuerySequence(Sequence):
     Use this to provide a sequence-like API around query results, such as
     being able to use len() and slicing, where the results objects don't
     natively provide them.
+
+    :param session: SQLAlchemy session object that will be used to query
+        the provided query with sequence like behavior.
+    :param query: The raw Select query from SQLAlchemy.
     """
-    def __init__(self, query=None):
+    def __init__(self, session, query=None):
         super().__init__()
         self._query = query
+        self.session = session
 
     def __len__(self):
-        return (0 if self._query is None else self._query.count())
+        return (
+            0 if self._query is None
+            else (
+                self
+                .session
+                .scalars(select(func.count()).select_from(self._query))
+                .one())
+            )
 
     def __getitem__(self, index):
         if self._query is None:
             raise IndexError('index out of range')
-        return self._query[index]
+        if isinstance(index, slice):
+            if index.step is not None:
+                raise IndexError(
+                    'Steps are not supported for QuerySequence')
+            return (
+                self
+                .session
+                .scalars(self._query.slice(index.start, index.stop))
+                .all()
+                )
+        else:
+            return (
+                self
+                .session
+                .scalars(self._query.offset(index).limit(1))
+                .one()
+                )
 
     def __iter__(self):
         if self._query is None:
             return []
-        yield from self._query
+        yield from self.session.execute(self._query).scalars()
